@@ -32,13 +32,21 @@
 #include <string.h>
 #include <dirent.h>
 #include <errno.h>
-#include <sys/time.h>
-#include <time.h>
-#include <inttypes.h>
 #include <assert.h>
 #include <unistd.h>
 #include <fcntl.h>
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #include <libprelude/prelude-list.h>
 #include <libprelude/prelude-linked-object.h>
 #include <libprelude/common.h>
@@ -217,7 +225,7 @@ int preludedb_sql_enable_query_logging(preludedb_sql_t *sql, const char *filenam
         sql->logfile = fopen(filename, "a");
         if ( ! sql->logfile )
                 return preludedb_error_verbose(prelude_error_code_from_errno(errno),
-                                               "Could not open '%s' for writing: %s", sql->logfile, strerror(errno));
+                                               "Could not open '%s' for writing: %s", filename, strerror(errno));
         
         fd = fileno(sql->logfile);
         
